from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.StepData import *
from OCC.Core.Interface import *
from OCC.Core.StepVisual import *


class RWStepVisual_RWAnnotationCurveOccurrence:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_AnnotationCurveOccurrence) -> None: ...
	def Share(self, ent: StepVisual_AnnotationCurveOccurrence, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_AnnotationCurveOccurrence) -> None: ...

class RWStepVisual_RWAnnotationCurveOccurrenceAndGeomReprItem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_AnnotationCurveOccurrenceAndGeomReprItem) -> None: ...
	def Share(self, ent: StepVisual_AnnotationCurveOccurrenceAndGeomReprItem, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_AnnotationCurveOccurrenceAndGeomReprItem) -> None: ...

class RWStepVisual_RWAnnotationFillArea:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_AnnotationFillArea) -> None: ...
	def Share(self, ent: StepVisual_AnnotationFillArea, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_AnnotationFillArea) -> None: ...

class RWStepVisual_RWAnnotationFillAreaOccurrence:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_AnnotationFillAreaOccurrence) -> None: ...
	def Share(self, ent: StepVisual_AnnotationFillAreaOccurrence, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_AnnotationFillAreaOccurrence) -> None: ...

class RWStepVisual_RWAnnotationOccurrence:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_AnnotationOccurrence) -> None: ...
	def Share(self, ent: StepVisual_AnnotationOccurrence, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_AnnotationOccurrence) -> None: ...

class RWStepVisual_RWAnnotationPlane:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_AnnotationPlane) -> None: ...
	def Share(self, ent: StepVisual_AnnotationPlane, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_AnnotationPlane) -> None: ...

class RWStepVisual_RWAreaInSet:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_AreaInSet) -> None: ...
	def Share(self, ent: StepVisual_AreaInSet, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_AreaInSet) -> None: ...

class RWStepVisual_RWBackgroundColour:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_BackgroundColour) -> None: ...
	def Share(self, ent: StepVisual_BackgroundColour, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_BackgroundColour) -> None: ...

class RWStepVisual_RWCameraImage:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CameraImage) -> None: ...
	def Share(self, ent: StepVisual_CameraImage, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CameraImage) -> None: ...

class RWStepVisual_RWCameraModel:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CameraModel) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CameraModel) -> None: ...

class RWStepVisual_RWCameraModelD2:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CameraModelD2) -> None: ...
	def Share(self, ent: StepVisual_CameraModelD2, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CameraModelD2) -> None: ...

class RWStepVisual_RWCameraModelD3:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CameraModelD3) -> None: ...
	def Share(self, ent: StepVisual_CameraModelD3, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CameraModelD3) -> None: ...

class RWStepVisual_RWCameraModelD3MultiClipping:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CameraModelD3MultiClipping) -> None: ...
	def Share(self, ent: StepVisual_CameraModelD3MultiClipping, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CameraModelD3MultiClipping) -> None: ...

class RWStepVisual_RWCameraModelD3MultiClippingIntersection:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CameraModelD3MultiClippingIntersection) -> None: ...
	def Share(self, ent: StepVisual_CameraModelD3MultiClippingIntersection, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CameraModelD3MultiClippingIntersection) -> None: ...

class RWStepVisual_RWCameraModelD3MultiClippingUnion:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CameraModelD3MultiClippingUnion) -> None: ...
	def Share(self, ent: StepVisual_CameraModelD3MultiClippingUnion, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CameraModelD3MultiClippingUnion) -> None: ...

class RWStepVisual_RWCameraUsage:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CameraUsage) -> None: ...
	def Share(self, ent: StepVisual_CameraUsage, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CameraUsage) -> None: ...

class RWStepVisual_RWCharacterizedObjAndRepresentationAndDraughtingModel:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel) -> None: ...
	def Share(self, ent: StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CharacterizedObjAndRepresentationAndDraughtingModel) -> None: ...

class RWStepVisual_RWColour:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_Colour) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_Colour) -> None: ...

class RWStepVisual_RWColourRgb:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_ColourRgb) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_ColourRgb) -> None: ...

class RWStepVisual_RWColourSpecification:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_ColourSpecification) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_ColourSpecification) -> None: ...

class RWStepVisual_RWCompositeText:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CompositeText) -> None: ...
	def Share(self, ent: StepVisual_CompositeText, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CompositeText) -> None: ...

class RWStepVisual_RWCompositeTextWithExtent:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CompositeTextWithExtent) -> None: ...
	def Share(self, ent: StepVisual_CompositeTextWithExtent, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CompositeTextWithExtent) -> None: ...

class RWStepVisual_RWContextDependentInvisibility:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_ContextDependentInvisibility) -> None: ...
	def Share(self, ent: StepVisual_ContextDependentInvisibility, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_ContextDependentInvisibility) -> None: ...

class RWStepVisual_RWContextDependentOverRidingStyledItem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_ContextDependentOverRidingStyledItem) -> None: ...
	def Share(self, ent: StepVisual_ContextDependentOverRidingStyledItem, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_ContextDependentOverRidingStyledItem) -> None: ...

class RWStepVisual_RWCoordinatesList:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CoordinatesList) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CoordinatesList) -> None: ...

class RWStepVisual_RWCurveStyle:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CurveStyle) -> None: ...
	def Share(self, ent: StepVisual_CurveStyle, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CurveStyle) -> None: ...

class RWStepVisual_RWCurveStyleFont:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CurveStyleFont) -> None: ...
	def Share(self, ent: StepVisual_CurveStyleFont, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CurveStyleFont) -> None: ...

class RWStepVisual_RWCurveStyleFontPattern:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_CurveStyleFontPattern) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_CurveStyleFontPattern) -> None: ...

class RWStepVisual_RWDraughtingCallout:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_DraughtingCallout) -> None: ...
	def Share(self, ent: StepVisual_DraughtingCallout, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_DraughtingCallout) -> None: ...

class RWStepVisual_RWDraughtingModel:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_DraughtingModel) -> None: ...
	def Share(self, ent: StepVisual_DraughtingModel, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_DraughtingModel) -> None: ...

class RWStepVisual_RWDraughtingPreDefinedColour:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_DraughtingPreDefinedColour) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_DraughtingPreDefinedColour) -> None: ...

class RWStepVisual_RWDraughtingPreDefinedCurveFont:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_DraughtingPreDefinedCurveFont) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_DraughtingPreDefinedCurveFont) -> None: ...

class RWStepVisual_RWExternallyDefinedCurveFont:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_ExternallyDefinedCurveFont) -> None: ...
	def Share(self, ent: StepVisual_ExternallyDefinedCurveFont, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_ExternallyDefinedCurveFont) -> None: ...

class RWStepVisual_RWFillAreaStyle:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_FillAreaStyle) -> None: ...
	def Share(self, ent: StepVisual_FillAreaStyle, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_FillAreaStyle) -> None: ...

class RWStepVisual_RWFillAreaStyleColour:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_FillAreaStyleColour) -> None: ...
	def Share(self, ent: StepVisual_FillAreaStyleColour, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_FillAreaStyleColour) -> None: ...

class RWStepVisual_RWInvisibility:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_Invisibility) -> None: ...
	def Share(self, ent: StepVisual_Invisibility, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_Invisibility) -> None: ...

class RWStepVisual_RWMechanicalDesignGeometricPresentationArea:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_MechanicalDesignGeometricPresentationArea) -> None: ...
	def Share(self, ent: StepVisual_MechanicalDesignGeometricPresentationArea, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_MechanicalDesignGeometricPresentationArea) -> None: ...

class RWStepVisual_RWMechanicalDesignGeometricPresentationRepresentation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_MechanicalDesignGeometricPresentationRepresentation) -> None: ...
	def Share(self, ent: StepVisual_MechanicalDesignGeometricPresentationRepresentation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_MechanicalDesignGeometricPresentationRepresentation) -> None: ...

class RWStepVisual_RWOverRidingStyledItem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_OverRidingStyledItem) -> None: ...
	def Share(self, ent: StepVisual_OverRidingStyledItem, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_OverRidingStyledItem) -> None: ...

class RWStepVisual_RWPlanarBox:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PlanarBox) -> None: ...
	def Share(self, ent: StepVisual_PlanarBox, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PlanarBox) -> None: ...

class RWStepVisual_RWPlanarExtent:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PlanarExtent) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PlanarExtent) -> None: ...

class RWStepVisual_RWPointStyle:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PointStyle) -> None: ...
	def Share(self, ent: StepVisual_PointStyle, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PointStyle) -> None: ...

class RWStepVisual_RWPreDefinedColour:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PreDefinedColour) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PreDefinedColour) -> None: ...

class RWStepVisual_RWPreDefinedCurveFont:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PreDefinedCurveFont) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PreDefinedCurveFont) -> None: ...

class RWStepVisual_RWPreDefinedItem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PreDefinedItem) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PreDefinedItem) -> None: ...

class RWStepVisual_RWPresentationArea:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PresentationArea) -> None: ...
	def Share(self, ent: StepVisual_PresentationArea, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PresentationArea) -> None: ...

class RWStepVisual_RWPresentationLayerAssignment:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PresentationLayerAssignment) -> None: ...
	def Share(self, ent: StepVisual_PresentationLayerAssignment, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PresentationLayerAssignment) -> None: ...

class RWStepVisual_RWPresentationLayerUsage:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PresentationLayerUsage) -> None: ...
	def Share(self, ent: StepVisual_PresentationLayerUsage, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PresentationLayerUsage) -> None: ...

class RWStepVisual_RWPresentationRepresentation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PresentationRepresentation) -> None: ...
	def Share(self, ent: StepVisual_PresentationRepresentation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PresentationRepresentation) -> None: ...

class RWStepVisual_RWPresentationSet:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PresentationSet) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PresentationSet) -> None: ...

class RWStepVisual_RWPresentationSize:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PresentationSize) -> None: ...
	def Share(self, ent: StepVisual_PresentationSize, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PresentationSize) -> None: ...

class RWStepVisual_RWPresentationStyleAssignment:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PresentationStyleAssignment) -> None: ...
	def Share(self, ent: StepVisual_PresentationStyleAssignment, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PresentationStyleAssignment) -> None: ...

class RWStepVisual_RWPresentationStyleByContext:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PresentationStyleByContext) -> None: ...
	def Share(self, ent: StepVisual_PresentationStyleByContext, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PresentationStyleByContext) -> None: ...

class RWStepVisual_RWPresentationView:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PresentationView) -> None: ...
	def Share(self, ent: StepVisual_PresentationView, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PresentationView) -> None: ...

class RWStepVisual_RWPresentedItemRepresentation:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_PresentedItemRepresentation) -> None: ...
	def Share(self, ent: StepVisual_PresentedItemRepresentation, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_PresentedItemRepresentation) -> None: ...

class RWStepVisual_RWStyledItem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_StyledItem) -> None: ...
	def Share(self, ent: StepVisual_StyledItem, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_StyledItem) -> None: ...

class RWStepVisual_RWSurfaceSideStyle:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_SurfaceSideStyle) -> None: ...
	def Share(self, ent: StepVisual_SurfaceSideStyle, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_SurfaceSideStyle) -> None: ...

class RWStepVisual_RWSurfaceStyleBoundary:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_SurfaceStyleBoundary) -> None: ...
	def Share(self, ent: StepVisual_SurfaceStyleBoundary, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_SurfaceStyleBoundary) -> None: ...

class RWStepVisual_RWSurfaceStyleControlGrid:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_SurfaceStyleControlGrid) -> None: ...
	def Share(self, ent: StepVisual_SurfaceStyleControlGrid, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_SurfaceStyleControlGrid) -> None: ...

class RWStepVisual_RWSurfaceStyleFillArea:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_SurfaceStyleFillArea) -> None: ...
	def Share(self, ent: StepVisual_SurfaceStyleFillArea, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_SurfaceStyleFillArea) -> None: ...

class RWStepVisual_RWSurfaceStyleParameterLine:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_SurfaceStyleParameterLine) -> None: ...
	def Share(self, ent: StepVisual_SurfaceStyleParameterLine, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_SurfaceStyleParameterLine) -> None: ...

class RWStepVisual_RWSurfaceStyleReflectanceAmbient:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_SurfaceStyleReflectanceAmbient) -> None: ...
	def Share(self, ent: StepVisual_SurfaceStyleReflectanceAmbient, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_SurfaceStyleReflectanceAmbient) -> None: ...

class RWStepVisual_RWSurfaceStyleRendering:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_SurfaceStyleRendering) -> None: ...
	def Share(self, ent: StepVisual_SurfaceStyleRendering, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_SurfaceStyleRendering) -> None: ...

class RWStepVisual_RWSurfaceStyleRenderingWithProperties:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_SurfaceStyleRenderingWithProperties) -> None: ...
	def Share(self, ent: StepVisual_SurfaceStyleRenderingWithProperties, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_SurfaceStyleRenderingWithProperties) -> None: ...

class RWStepVisual_RWSurfaceStyleSegmentationCurve:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_SurfaceStyleSegmentationCurve) -> None: ...
	def Share(self, ent: StepVisual_SurfaceStyleSegmentationCurve, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_SurfaceStyleSegmentationCurve) -> None: ...

class RWStepVisual_RWSurfaceStyleSilhouette:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_SurfaceStyleSilhouette) -> None: ...
	def Share(self, ent: StepVisual_SurfaceStyleSilhouette, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_SurfaceStyleSilhouette) -> None: ...

class RWStepVisual_RWSurfaceStyleTransparent:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_SurfaceStyleTransparent) -> None: ...
	def Share(self, ent: StepVisual_SurfaceStyleTransparent, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_SurfaceStyleTransparent) -> None: ...

class RWStepVisual_RWSurfaceStyleUsage:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_SurfaceStyleUsage) -> None: ...
	def Share(self, ent: StepVisual_SurfaceStyleUsage, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_SurfaceStyleUsage) -> None: ...

class RWStepVisual_RWTemplate:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_Template) -> None: ...
	def Share(self, ent: StepVisual_Template, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_Template) -> None: ...

class RWStepVisual_RWTemplateInstance:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_TemplateInstance) -> None: ...
	def Share(self, ent: StepVisual_TemplateInstance, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_TemplateInstance) -> None: ...

class RWStepVisual_RWTessellatedAnnotationOccurrence:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_TessellatedAnnotationOccurrence) -> None: ...
	def Share(self, ent: StepVisual_TessellatedAnnotationOccurrence, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_TessellatedAnnotationOccurrence) -> None: ...

class RWStepVisual_RWTessellatedCurveSet:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_TessellatedCurveSet) -> None: ...
	def Share(self, ent: StepVisual_TessellatedCurveSet, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_TessellatedCurveSet) -> None: ...

class RWStepVisual_RWTessellatedGeometricSet:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_TessellatedGeometricSet) -> None: ...
	def Share(self, ent: StepVisual_TessellatedGeometricSet, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_TessellatedGeometricSet) -> None: ...

class RWStepVisual_RWTessellatedItem:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_TessellatedItem) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_TessellatedItem) -> None: ...

class RWStepVisual_RWTextLiteral:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_TextLiteral) -> None: ...
	def Share(self, ent: StepVisual_TextLiteral, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_TextLiteral) -> None: ...

class RWStepVisual_RWTextStyle:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_TextStyle) -> None: ...
	def Share(self, ent: StepVisual_TextStyle, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_TextStyle) -> None: ...

class RWStepVisual_RWTextStyleForDefinedFont:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_TextStyleForDefinedFont) -> None: ...
	def Share(self, ent: StepVisual_TextStyleForDefinedFont, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_TextStyleForDefinedFont) -> None: ...

class RWStepVisual_RWTextStyleWithBoxCharacteristics:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_TextStyleWithBoxCharacteristics) -> None: ...
	def Share(self, ent: StepVisual_TextStyleWithBoxCharacteristics, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_TextStyleWithBoxCharacteristics) -> None: ...

class RWStepVisual_RWViewVolume:
	def __init__(self) -> None: ...
	def ReadStep(self, data: StepData_StepReaderData, num: int, ach: Interface_Check, ent: StepVisual_ViewVolume) -> None: ...
	def Share(self, ent: StepVisual_ViewVolume, iter: Interface_EntityIterator) -> None: ...
	def WriteStep(self, SW: StepData_StepWriter, ent: StepVisual_ViewVolume) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BRepProj module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_brepproj.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BRepProj
else:
    import _BRepProj

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BRepProj.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BRepProj.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepProj.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepProj.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BRepProj.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BRepProj.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BRepProj.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BRepProj.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BRepProj.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BRepProj.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepProj.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BRepProj.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BRepProj.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepProj.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepProj.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepProj.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BRepProj.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BRepProj:
_BRepProj.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BRepProj.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp

from enum import IntEnum
from OCC.Core.Exception import *



class BRepProj_Projection(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Makes a cylindrical projection of wire om shape.

        Parameters
        ----------
        Wire: TopoDS_Shape
        Shape: TopoDS_Shape
        D: gp_Dir

        Returns
        -------
        None
        Makes a conical projection of wire om shape.

        Parameters
        ----------
        Wire: TopoDS_Shape
        Shape: TopoDS_Shape
        P: gp_Pnt

        Returns
        -------
        None

        """
        _BRepProj.BRepProj_Projection_swiginit(self, _BRepProj.new_BRepProj_Projection(*args))

    def Current(self, *args) -> "TopoDS_Wire":
        r"""
        Returns the current result wire.

        Returns
        -------
        TopoDS_Wire

        """
        return _BRepProj.BRepProj_Projection_Current(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Resets the iterator by resulting wires.

        Returns
        -------
        None

        """
        return _BRepProj.BRepProj_Projection_Init(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns false if the section failed.

        Returns
        -------
        bool

        """
        return _BRepProj.BRepProj_Projection_IsDone(self, *args)

    def More(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if there is a current result wire.

        Returns
        -------
        bool

        """
        return _BRepProj.BRepProj_Projection_More(self, *args)

    def Next(self, *args) -> "void":
        r"""
        Move to the next result wire.

        Returns
        -------
        None

        """
        return _BRepProj.BRepProj_Projection_Next(self, *args)

    def Shape(self, *args) -> "TopoDS_Compound":
        r"""
        Returns the complete result as compound of wires.

        Returns
        -------
        TopoDS_Compound

        """
        return _BRepProj.BRepProj_Projection_Shape(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepProj.delete_BRepProj_Projection

# Register BRepProj_Projection in _BRepProj:
_BRepProj.BRepProj_Projection_swigregister(BRepProj_Projection)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom import *
from OCC.Core.gp import *
from OCC.Core.TColgp import *
from OCC.Core.Adaptor3d import *
from OCC.Core.GeomAbs import *
from OCC.Core.TColStd import *
from OCC.Core.Geom2d import *
from OCC.Core.Adaptor2d import *
from OCC.Core.math import *
from OCC.Core.AdvApprox import *

GeomLib_DenominatorMultiplierPtr = NewType('GeomLib_DenominatorMultiplierPtr', GeomLib_DenominatorMultiplier)

class GeomLib_Array1OfMat:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> gp_Mat: ...
    def __setitem__(self, index: int, value: gp_Mat) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[gp_Mat]: ...
    def next(self) -> gp_Mat: ...
    __next__ = next
    def Init(self, theValue: gp_Mat) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> gp_Mat: ...
    def Last(self) -> gp_Mat: ...
    def Value(self, theIndex: int) -> gp_Mat: ...
    def SetValue(self, theIndex: int, theValue: gp_Mat) -> None: ...

class GeomLib_InterpolationErrors(IntEnum):
	GeomLib_NoError: int = ...
	GeomLib_NotEnoughtPoints: int = ...
	GeomLib_DegreeSmallerThan3: int = ...
	GeomLib_InversionProblem: int = ...
GeomLib_NoError = GeomLib_InterpolationErrors.GeomLib_NoError
GeomLib_NotEnoughtPoints = GeomLib_InterpolationErrors.GeomLib_NotEnoughtPoints
GeomLib_DegreeSmallerThan3 = GeomLib_InterpolationErrors.GeomLib_DegreeSmallerThan3
GeomLib_InversionProblem = GeomLib_InterpolationErrors.GeomLib_InversionProblem

class geomlib:
	@staticmethod
	def AdjustExtremity(Curve: Geom_BoundedCurve, P1: gp_Pnt, P2: gp_Pnt, T1: gp_Vec, T2: gp_Vec) -> None: ...
	@staticmethod
	def AxeOfInertia(Points: TColgp_Array1OfPnt, Axe: gp_Ax2, Tol: Optional[float] = 1.0e-7) -> bool: ...
	@staticmethod
	def BuildCurve3d(Tolerance: float, CurvePtr: Adaptor3d_CurveOnSurface, FirstParameter: float, LastParameter: float, NewCurvePtr: Geom_Curve, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C1, MaxDegree: Optional[int] = 14, MaxSegment: Optional[int] = 30) -> Tuple[float, float]: ...
	@staticmethod
	def CancelDenominatorDerivative(BSurf: Geom_BSplineSurface, UDirection: bool, VDirection: bool) -> None: ...
	@staticmethod
	def DensifyArray1OfReal(MinNumPoints: int, InParameters: TColStd_Array1OfReal, OutParameters: TColStd_HArray1OfReal) -> None: ...
	@staticmethod
	def EvalMaxDistanceAlongParameter(Curve: Adaptor3d_Curve, AReferenceCurve: Adaptor3d_Curve, Tolerance: float, Parameters: TColStd_Array1OfReal) -> float: ...
	@staticmethod
	def EvalMaxParametricDistance(Curve: Adaptor3d_Curve, AReferenceCurve: Adaptor3d_Curve, Tolerance: float, Parameters: TColStd_Array1OfReal) -> float: ...
	@staticmethod
	def ExtendCurveToPoint(Curve: Geom_BoundedCurve, Point: gp_Pnt, Cont: int, After: bool) -> None: ...
	@staticmethod
	def ExtendSurfByLength(Surf: Geom_BoundedSurface, Length: float, Cont: int, InU: bool, After: bool) -> None: ...
	@staticmethod
	def FuseIntervals(Interval1: TColStd_Array1OfReal, Interval2: TColStd_Array1OfReal, Fusion: TColStd_SequenceOfReal, Confusion: Optional[float] = 1.0e-9) -> None: ...
	@staticmethod
	def GTransform(Curve: Geom2d_Curve, GTrsf: gp_GTrsf2d) -> Geom2d_Curve: ...
	@staticmethod
	def Inertia(Points: TColgp_Array1OfPnt, Bary: gp_Pnt, XDir: gp_Dir, YDir: gp_Dir) -> Tuple[float, float, float]: ...
	@staticmethod
	def IsBSplUClosed(S: Geom_BSplineSurface, U1: float, U2: float, Tol: float) -> bool: ...
	@staticmethod
	def IsBSplVClosed(S: Geom_BSplineSurface, V1: float, V2: float, Tol: float) -> bool: ...
	@staticmethod
	def IsBzUClosed(S: Geom_BezierSurface, U1: float, U2: float, Tol: float) -> bool: ...
	@staticmethod
	def IsBzVClosed(S: Geom_BezierSurface, V1: float, V2: float, Tol: float) -> bool: ...
	@staticmethod
	def IsClosed(S: Geom_Surface, Tol: float) -> Tuple[bool, bool]: ...
	@staticmethod
	def NormEstim(S: Geom_Surface, UV: gp_Pnt2d, Tol: float, N: gp_Dir) -> int: ...
	@staticmethod
	def RemovePointsFromArray(NumPoints: int, InParameters: TColStd_Array1OfReal, OutParameters: TColStd_HArray1OfReal) -> None: ...
	@staticmethod
	def SameRange(Tolerance: float, Curve2dPtr: Geom2d_Curve, First: float, Last: float, RequestedFirst: float, RequestedLast: float, NewCurve2dPtr: Geom2d_Curve) -> None: ...
	@staticmethod
	def To3d(Position: gp_Ax2, Curve2d: Geom2d_Curve) -> Geom_Curve: ...
	@staticmethod
	def buildC3dOnIsoLine(theC2D: Adaptor2d_HCurve2d, theSurf: Adaptor3d_HSurface, theFirst: float, theLast: float, theTolerance: float, theIsU: bool, theParam: float, theIsForward: bool) -> Geom_Curve: ...
	@staticmethod
	def isIsoLine(theC2D: Adaptor2d_HCurve2d) -> Tuple[bool, bool, float, bool]: ...

class GeomLib_Check2dBSplineCurve:
	def __init__(self, Curve: Geom2d_BSplineCurve, Tolerance: float, AngularTolerance: float) -> None: ...
	def FixTangent(self, FirstFlag: bool, LastFlag: bool) -> None: ...
	def FixedTangent(self, FirstFlag: bool, LastFlag: bool) -> Geom2d_BSplineCurve: ...
	def IsDone(self) -> bool: ...
	def NeedTangentFix(self) -> Tuple[bool, bool]: ...

class GeomLib_CheckBSplineCurve:
	def __init__(self, Curve: Geom_BSplineCurve, Tolerance: float, AngularTolerance: float) -> None: ...
	def FixTangent(self, FirstFlag: bool, LastFlag: bool) -> None: ...
	def FixedTangent(self, FirstFlag: bool, LastFlag: bool) -> Geom_BSplineCurve: ...
	def IsDone(self) -> bool: ...
	def NeedTangentFix(self) -> Tuple[bool, bool]: ...

class GeomLib_CheckCurveOnSurface:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theCurve: Geom_Curve, theSurface: Geom_Surface, theFirst: float, theLast: float, theTolRange: Optional[float] = precision_PConfusion()) -> None: ...
	def Curve(self) -> Geom_Curve: ...
	def ErrorStatus(self) -> int: ...
	@overload
	def Init(self, theCurve: Geom_Curve, theSurface: Geom_Surface, theFirst: float, theLast: float, theTolRange: Optional[float] = precision_PConfusion()) -> None: ...
	@overload
	def Init(self) -> None: ...
	def IsDone(self) -> bool: ...
	def MaxDistance(self) -> float: ...
	def MaxParameter(self) -> float: ...
	def Perform(self, thePCurve: Geom2d_Curve, isTheMultyTheradDisabled: Optional[bool] = False) -> None: ...
	def Range(self) -> Tuple[float, float]: ...
	def Surface(self) -> Geom_Surface: ...

class GeomLib_DenominatorMultiplier:
	def __init__(self, Surface: Geom_BSplineSurface, KnotVector: TColStd_Array1OfReal) -> None: ...
	def Value(self, UParameter: float, VParameter: float) -> float: ...

class GeomLib_Interpolate:
	def __init__(self, Degree: int, NumPoints: int, Points: TColgp_Array1OfPnt, Parameters: TColStd_Array1OfReal) -> None: ...
	def Curve(self) -> Geom_BSplineCurve: ...
	def Error(self) -> GeomLib_InterpolationErrors: ...
	def IsDone(self) -> bool: ...

class GeomLib_IsPlanarSurface:
	def __init__(self, S: Geom_Surface, Tol: Optional[float] = 1.0e-7) -> None: ...
	def IsPlanar(self) -> bool: ...
	def Plan(self) -> gp_Pln: ...

class GeomLib_LogSample(math_FunctionSample):
	def __init__(self, A: float, B: float, N: int) -> None: ...
	def GetParameter(self, Index: int) -> float: ...

class GeomLib_MakeCurvefromApprox:
	def __init__(self, Approx: AdvApprox_ApproxAFunction) -> None: ...
	@overload
	def Curve(self, Index3d: int) -> Geom_BSplineCurve: ...
	@overload
	def Curve(self, Index1D: int, Index3D: int) -> Geom_BSplineCurve: ...
	@overload
	def Curve2d(self, Index2d: int) -> Geom2d_BSplineCurve: ...
	@overload
	def Curve2d(self, Index1d: int, Index2d: int) -> Geom2d_BSplineCurve: ...
	def Curve2dFromTwo1d(self, Index1d: int, Index2d: int) -> Geom2d_BSplineCurve: ...
	def IsDone(self) -> bool: ...
	def Nb1DSpaces(self) -> int: ...
	def Nb2DSpaces(self) -> int: ...
	def Nb3DSpaces(self) -> int: ...

class GeomLib_PolyFunc(math_FunctionWithDerivative):
	def __init__(self, Coeffs: math_Vector) -> None: ...
	def Derivative(self, X: float) -> Tuple[bool, float]: ...
	def Value(self, X: float) -> Tuple[bool, float]: ...
	def Values(self, X: float) -> Tuple[bool, float, float]: ...

class GeomLib_Tool:
	@overload
	@staticmethod
	def Parameter(Curve: Geom_Curve, Point: gp_Pnt, MaxDist: float) -> Tuple[bool, float]: ...
	@overload
	@staticmethod
	def Parameter(Curve: Geom2d_Curve, Point: gp_Pnt2d, MaxDist: float) -> Tuple[bool, float]: ...
	@staticmethod
	def Parameters(Surface: Geom_Surface, Point: gp_Pnt, MaxDist: float) -> Tuple[bool, float, float]: ...

# harray1 classes
# harray2 classes
# hsequence classes

geomlib_AdjustExtremity = geomlib.AdjustExtremity
geomlib_AxeOfInertia = geomlib.AxeOfInertia
geomlib_BuildCurve3d = geomlib.BuildCurve3d
geomlib_CancelDenominatorDerivative = geomlib.CancelDenominatorDerivative
geomlib_DensifyArray1OfReal = geomlib.DensifyArray1OfReal
geomlib_EvalMaxDistanceAlongParameter = geomlib.EvalMaxDistanceAlongParameter
geomlib_EvalMaxParametricDistance = geomlib.EvalMaxParametricDistance
geomlib_ExtendCurveToPoint = geomlib.ExtendCurveToPoint
geomlib_ExtendSurfByLength = geomlib.ExtendSurfByLength
geomlib_FuseIntervals = geomlib.FuseIntervals
geomlib_GTransform = geomlib.GTransform
geomlib_Inertia = geomlib.Inertia
geomlib_IsBSplUClosed = geomlib.IsBSplUClosed
geomlib_IsBSplVClosed = geomlib.IsBSplVClosed
geomlib_IsBzUClosed = geomlib.IsBzUClosed
geomlib_IsBzVClosed = geomlib.IsBzVClosed
geomlib_IsClosed = geomlib.IsClosed
geomlib_NormEstim = geomlib.NormEstim
geomlib_RemovePointsFromArray = geomlib.RemovePointsFromArray
geomlib_SameRange = geomlib.SameRange
geomlib_To3d = geomlib.To3d
geomlib_buildC3dOnIsoLine = geomlib.buildC3dOnIsoLine
geomlib_isIsoLine = geomlib.isIsoLine
GeomLib_Tool_Parameter = GeomLib_Tool.Parameter
GeomLib_Tool_Parameter = GeomLib_Tool.Parameter
GeomLib_Tool_Parameters = GeomLib_Tool.Parameters



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
SelectBasics module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_selectbasics.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _SelectBasics
else:
    import _SelectBasics

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _SelectBasics.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _SelectBasics.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _SelectBasics.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _SelectBasics.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _SelectBasics.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _SelectBasics.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _SelectBasics.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _SelectBasics.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _SelectBasics.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _SelectBasics.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _SelectBasics.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _SelectBasics.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _SelectBasics.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _SelectBasics.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _SelectBasics.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _SelectBasics.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _SelectBasics.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _SelectBasics:
_SelectBasics.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _SelectBasics.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.TColgp

from enum import IntEnum
from OCC.Core.Exception import *



class selectbasics(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def MaxOwnerPriority(*args) -> "Standard_Integer":
        r"""
        Structure to provide all-in-one result of selection of sensitive for 'matches' method of select3d_sensitiveentity.

        Returns
        -------
        int

        """
        return _SelectBasics.selectbasics_MaxOwnerPriority(*args)

    @staticmethod
    def MinOwnerPriority(*args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _SelectBasics.selectbasics_MinOwnerPriority(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _SelectBasics.selectbasics_swiginit(self, _SelectBasics.new_selectbasics())
    __swig_destroy__ = _SelectBasics.delete_selectbasics

# Register selectbasics in _SelectBasics:
_SelectBasics.selectbasics_swigregister(selectbasics)

def selectbasics_MaxOwnerPriority(*args) -> "Standard_Integer":
    r"""
    Structure to provide all-in-one result of selection of sensitive for 'matches' method of select3d_sensitiveentity.

    Returns
    -------
    int

    """
    return _SelectBasics.selectbasics_MaxOwnerPriority(*args)

def selectbasics_MinOwnerPriority(*args) -> "Standard_Integer":
    r"""
    No available documentation.

    Returns
    -------
    int

    """
    return _SelectBasics.selectbasics_MinOwnerPriority(*args)

class SelectBasics_PickResult(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor defining an invalid result.

        Returns
        -------
        None
        Constructor with initialization.

        Parameters
        ----------
        theDepth: float
        theDistToCenter: float
        theObjPickedPnt: gp_Pnt

        Returns
        -------
        None

        """
        _SelectBasics.SelectBasics_PickResult_swiginit(self, _SelectBasics.new_SelectBasics_PickResult(*args))

    def Depth(self, *args) -> "Standard_Real":
        r"""
        Return depth along picking ray.

        Returns
        -------
        float

        """
        return _SelectBasics.SelectBasics_PickResult_Depth(self, *args)

    def DistToGeomCenter(self, *args) -> "Standard_Real":
        r"""
        Return distance to geometry center (auxiliary value for comparing results).

        Returns
        -------
        float

        """
        return _SelectBasics.SelectBasics_PickResult_DistToGeomCenter(self, *args)

    def HasPickedPoint(self, *args) -> "Standard_Boolean":
        r"""
        Return true if picked point lying on detected entity was set.

        Returns
        -------
        bool

        """
        return _SelectBasics.SelectBasics_PickResult_HasPickedPoint(self, *args)

    def Invalidate(self, *args) -> "void":
        r"""
        Reset depth value.

        Returns
        -------
        None

        """
        return _SelectBasics.SelectBasics_PickResult_Invalidate(self, *args)

    def IsValid(self, *args) -> "Standard_Boolean":
        r"""
        Return true if result was been defined.

        Returns
        -------
        bool

        """
        return _SelectBasics.SelectBasics_PickResult_IsValid(self, *args)

    @staticmethod
    def Min(*args) -> "SelectBasics_PickResult const &":
        r"""
        Return closest result between two pick results according to depth value.

        Parameters
        ----------
        thePickResult1: SelectBasics_PickResult
        thePickResult2: SelectBasics_PickResult

        Returns
        -------
        SelectBasics_PickResult

        """
        return _SelectBasics.SelectBasics_PickResult_Min(*args)

    def PickedPoint(self, *args) -> "gp_Pnt const":
        r"""
        Return picked point lying on detected entity. warning! point is defined in local coordinate system and should be translated into world system before usage!.

        Returns
        -------
        gp_Pnt

        """
        return _SelectBasics.SelectBasics_PickResult_PickedPoint(self, *args)

    def SetDepth(self, *args) -> "void":
        r"""
        Set depth along picking ray.

        Parameters
        ----------
        theDepth: float

        Returns
        -------
        None

        """
        return _SelectBasics.SelectBasics_PickResult_SetDepth(self, *args)

    def SetDistToGeomCenter(self, *args) -> "void":
        r"""
        Set distance to geometry center.

        Parameters
        ----------
        theDistToCenter: float

        Returns
        -------
        None

        """
        return _SelectBasics.SelectBasics_PickResult_SetDistToGeomCenter(self, *args)

    def SetPickedPoint(self, *args) -> "void":
        r"""
        Set picked point.

        Parameters
        ----------
        theObjPickedPnt: gp_Pnt

        Returns
        -------
        None

        """
        return _SelectBasics.SelectBasics_PickResult_SetPickedPoint(self, *args)

    def SetSurfaceNormal(self, *args) -> "void":
        r"""
        Set surface normal at picked point.

        Parameters
        ----------
        theNormal: NCollection_Vec3<float>

        Returns
        -------
        None
        Set surface normal at picked point.

        Parameters
        ----------
        theNormal: gp_Vec

        Returns
        -------
        None

        """
        return _SelectBasics.SelectBasics_PickResult_SetSurfaceNormal(self, *args)

    def SurfaceNormal(self, *args) -> "NCollection_Vec3< float > const &":
        r"""
        Return (unnormalized) surface normal at picked point or zero vector if undefined. warning! normal is defined in local coordinate system and should be translated into world system before usage!.

        Returns
        -------
        NCollection_Vec3<float>

        """
        return _SelectBasics.SelectBasics_PickResult_SurfaceNormal(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _SelectBasics.delete_SelectBasics_PickResult

# Register SelectBasics_PickResult in _SelectBasics:
_SelectBasics.SelectBasics_PickResult_swigregister(SelectBasics_PickResult)

def SelectBasics_PickResult_Min(*args) -> "SelectBasics_PickResult const &":
    r"""
    Return closest result between two pick results according to depth value.

    Parameters
    ----------
    thePickResult1: SelectBasics_PickResult
    thePickResult2: SelectBasics_PickResult

    Returns
    -------
    SelectBasics_PickResult

    """
    return _SelectBasics.SelectBasics_PickResult_Min(*args)

class SelectBasics_SelectingVolumeManager(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    Point = _SelectBasics.SelectBasics_SelectingVolumeManager_Point
    Box = _SelectBasics.SelectBasics_SelectingVolumeManager_Box
    Polyline = _SelectBasics.SelectBasics_SelectingVolumeManager_Polyline
    Unknown = _SelectBasics.SelectBasics_SelectingVolumeManager_Unknown


    class SelectionType(IntEnum):
    	Point = 0
    	Box = 1
    	Polyline = 2
    	Unknown = 3
    Point = SelectionType.Point
    Box = SelectionType.Box
    Polyline = SelectionType.Polyline
    Unknown = SelectionType.Unknown


    def DetectedPoint(self, *args) -> "gp_Pnt":
        r"""
        No available documentation.

        Parameters
        ----------
        theDepth: float

        Returns
        -------
        gp_Pnt

        """
        return _SelectBasics.SelectBasics_SelectingVolumeManager_DetectedPoint(self, *args)

    def DistToGeometryCenter(self, *args) -> "Standard_Real":
        r"""
        Calculates distance from 3d projection of user-defined selection point to the given point thecog.

        Parameters
        ----------
        theCOG: gp_Pnt

        Returns
        -------
        float

        """
        return _SelectBasics.SelectBasics_SelectingVolumeManager_DistToGeometryCenter(self, *args)

    def DumpJsonToString(self, depth: "int"=-1) -> "std::string":
        r"""DumpJsonToString(SelectBasics_SelectingVolumeManager self, int depth=-1) -> std::string"""
        return _SelectBasics.SelectBasics_SelectingVolumeManager_DumpJsonToString(self, depth)

    def GetActiveSelectionType(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Returns
        -------
        int

        """
        return _SelectBasics.SelectBasics_SelectingVolumeManager_GetActiveSelectionType(self, *args)

    def GetFarPickedPnt(self, *args) -> "gp_Pnt":
        r"""
        Valid only for point and rectangular selection. returns projection of 2d mouse picked point or projection of center of 2d rectangle (for point and rectangular selection correspondingly) onto far view frustum plane.

        Returns
        -------
        gp_Pnt

        """
        return _SelectBasics.SelectBasics_SelectingVolumeManager_GetFarPickedPnt(self, *args)

    def GetMousePosition(self, *args) -> "gp_Pnt2d":
        r"""
        Return mouse coordinates for point selection mode.

        Returns
        -------
        gp_Pnt2d

        """
        return _SelectBasics.SelectBasics_SelectingVolumeManager_GetMousePosition(self, *args)

    def GetNearPickedPnt(self, *args) -> "gp_Pnt":
        r"""
        Valid only for point and rectangular selection. returns projection of 2d mouse picked point or projection of center of 2d rectangle (for point and rectangular selection correspondingly) onto near view frustum plane.

        Returns
        -------
        gp_Pnt

        """
        return _SelectBasics.SelectBasics_SelectingVolumeManager_GetNearPickedPnt(self, *args)

    def GetPlanes(self, *args) -> "void":
        r"""
        Stores plane equation coefficients (in the following form: ax + by + cz + d = 0) to the given vector.

        Parameters
        ----------
        thePlaneEquations: NCollection_Vector<NCollection_Vec4<float> >

        Returns
        -------
        None

        """
        return _SelectBasics.SelectBasics_SelectingVolumeManager_GetPlanes(self, *args)

    def IsOverlapAllowed(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _SelectBasics.SelectBasics_SelectingVolumeManager_IsOverlapAllowed(self, *args)

    def Overlaps(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if selecting volume is overlapped by box thebox.

        Parameters
        ----------
        theBoxMin: NCollection_Vec3<float>
        theBoxMax: NCollection_Vec3<float>
        thePickResult: SelectBasics_PickResult

        Returns
        -------
        bool
        Returns true if selecting volume is overlapped by axis-aligned bounding box with minimum corner at point theminpt and maximum at point themaxpt.

        Parameters
        ----------
        theBoxMin: NCollection_Vec3<float>
        theBoxMax: NCollection_Vec3<float>
        theInside: bool *,optional
        	default value is NULL

        Returns
        -------
        bool
        Returns true if selecting volume is overlapped by point thepnt.

        Parameters
        ----------
        thePnt: gp_Pnt
        thePickResult: SelectBasics_PickResult

        Returns
        -------
        bool
        Returns true if selecting volume is overlapped by point thepnt. does not perform depth calculation, so this method is defined as helper function for inclusion test.

        Parameters
        ----------
        thePnt: gp_Pnt

        Returns
        -------
        bool
        Returns true if selecting volume is overlapped by planar convex polygon, which points are stored in thearrayofpts, taking into account sensitivity type thesenstype.

        Parameters
        ----------
        theArrayOfPts: TColgp_HArray1OfPnt
        theSensType: int
        thePickResult: SelectBasics_PickResult

        Returns
        -------
        bool
        Returns true if selecting volume is overlapped by planar convex polygon, which points are stored in thearrayofpts, taking into account sensitivity type thesenstype.

        Parameters
        ----------
        theArrayOfPts: TColgp_Array1OfPnt
        theSensType: int
        thePickResult: SelectBasics_PickResult

        Returns
        -------
        bool
        Returns true if selecting volume is overlapped by line segment with start point at thept1 and end point at thept2.

        Parameters
        ----------
        thePt1: gp_Pnt
        thePt2: gp_Pnt
        thePickResult: SelectBasics_PickResult

        Returns
        -------
        bool
        Returns true if selecting volume is overlapped by triangle with vertices thept1, thept2 and thept3, taking into account sensitivity type thesenstype.

        Parameters
        ----------
        thePt1: gp_Pnt
        thePt2: gp_Pnt
        thePt3: gp_Pnt
        theSensType: int
        thePickResult: SelectBasics_PickResult

        Returns
        -------
        bool

        """
        return _SelectBasics.SelectBasics_SelectingVolumeManager_Overlaps(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _SelectBasics.delete_SelectBasics_SelectingVolumeManager

# Register SelectBasics_SelectingVolumeManager in _SelectBasics:
_SelectBasics.SelectBasics_SelectingVolumeManager_swigregister(SelectBasics_SelectingVolumeManager)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.BRepMesh import *


class xbrepmesh:
	@staticmethod
	def Discret(theShape: TopoDS_Shape, theDeflection: float, theAngle: float, theAlgo: BRepMesh_DiscretRoot) -> int: ...

# harray1 classes
# harray2 classes
# hsequence classes

xbrepmesh_Discret = xbrepmesh.Discret



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.ShapeBuild import *
from OCC.Core.Message import *
from OCC.Core.ShapeExtend import *
from OCC.Core.Geom import *
from OCC.Core.TopLoc import *
from OCC.Core.ShapeAnalysis import *
from OCC.Core.ShapeConstruct import *
from OCC.Core.Geom2d import *
from OCC.Core.TopAbs import *
from OCC.Core.TopTools import *


class ShapeFix_SequenceOfWireSegment:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> ShapeFix_WireSegment: ...
    def Last(self) -> ShapeFix_WireSegment: ...
    def Length(self) -> int: ...
    def Append(self, theItem: ShapeFix_WireSegment) -> ShapeFix_WireSegment: ...
    def Prepend(self, theItem: ShapeFix_WireSegment) -> ShapeFix_WireSegment: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> ShapeFix_WireSegment: ...
    def SetValue(self, theIndex: int, theValue: ShapeFix_WireSegment) -> None: ...

class shapefix:
	@staticmethod
	def EncodeRegularity(shape: TopoDS_Shape, tolang: Optional[float] = 1.0e-10) -> None: ...
	@staticmethod
	def FixVertexPosition(theshape: TopoDS_Shape, theTolerance: float, thecontext: ShapeBuild_ReShape) -> bool: ...
	@staticmethod
	def LeastEdgeSize(theshape: TopoDS_Shape) -> float: ...
	@staticmethod
	def RemoveSmallEdges(shape: TopoDS_Shape, Tolerance: float, context: ShapeBuild_ReShape) -> TopoDS_Shape: ...
	@staticmethod
	def SameParameter(shape: TopoDS_Shape, enforce: bool, preci: Optional[float] = 0.0, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange(), theMsgReg: Optional[ShapeExtend_BasicMsgRegistrator] = 0) -> bool: ...

class ShapeFix_Edge(Standard_Transient):
	def __init__(self) -> None: ...
	def FixAddCurve3d(self, edge: TopoDS_Edge) -> bool: ...
	@overload
	def FixAddPCurve(self, edge: TopoDS_Edge, face: TopoDS_Face, isSeam: bool, prec: Optional[float] = 0.0) -> bool: ...
	@overload
	def FixAddPCurve(self, edge: TopoDS_Edge, surface: Geom_Surface, location: TopLoc_Location, isSeam: bool, prec: Optional[float] = 0.0) -> bool: ...
	@overload
	def FixAddPCurve(self, edge: TopoDS_Edge, face: TopoDS_Face, isSeam: bool, surfana: ShapeAnalysis_Surface, prec: Optional[float] = 0.0) -> bool: ...
	@overload
	def FixAddPCurve(self, edge: TopoDS_Edge, surface: Geom_Surface, location: TopLoc_Location, isSeam: bool, surfana: ShapeAnalysis_Surface, prec: Optional[float] = 0.0) -> bool: ...
	def FixRemoveCurve3d(self, edge: TopoDS_Edge) -> bool: ...
	@overload
	def FixRemovePCurve(self, edge: TopoDS_Edge, face: TopoDS_Face) -> bool: ...
	@overload
	def FixRemovePCurve(self, edge: TopoDS_Edge, surface: Geom_Surface, location: TopLoc_Location) -> bool: ...
	@overload
	def FixReversed2d(self, edge: TopoDS_Edge, face: TopoDS_Face) -> bool: ...
	@overload
	def FixReversed2d(self, edge: TopoDS_Edge, surface: Geom_Surface, location: TopLoc_Location) -> bool: ...
	@overload
	def FixSameParameter(self, edge: TopoDS_Edge, tolerance: Optional[float] = 0.0) -> bool: ...
	@overload
	def FixSameParameter(self, edge: TopoDS_Edge, face: TopoDS_Face, tolerance: Optional[float] = 0.0) -> bool: ...
	@overload
	def FixVertexTolerance(self, edge: TopoDS_Edge, face: TopoDS_Face) -> bool: ...
	@overload
	def FixVertexTolerance(self, edge: TopoDS_Edge) -> bool: ...
	def Projector(self) -> ShapeConstruct_ProjectCurveOnSurface: ...
	def SetContext(self, context: ShapeBuild_ReShape) -> None: ...
	def Status(self, status: ShapeExtend_Status) -> bool: ...

class ShapeFix_EdgeConnect:
	def __init__(self) -> None: ...
	@overload
	def Add(self, aFirst: TopoDS_Edge, aSecond: TopoDS_Edge) -> None: ...
	@overload
	def Add(self, aShape: TopoDS_Shape) -> None: ...
	def Build(self) -> None: ...
	def Clear(self) -> None: ...

class ShapeFix_EdgeProjAux(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, F: TopoDS_Face, E: TopoDS_Edge) -> None: ...
	def Compute(self, preci: float) -> None: ...
	def FirstParam(self) -> float: ...
	def Init(self, F: TopoDS_Face, E: TopoDS_Edge) -> None: ...
	def IsFirstDone(self) -> bool: ...
	def IsIso(self, C: Geom2d_Curve) -> bool: ...
	def IsLastDone(self) -> bool: ...
	def LastParam(self) -> float: ...

class ShapeFix_FaceConnect:
	def __init__(self) -> None: ...
	def Add(self, aFirst: TopoDS_Face, aSecond: TopoDS_Face) -> bool: ...
	def Build(self, shell: TopoDS_Shell, sewtoler: float, fixtoler: float) -> TopoDS_Shell: ...
	def Clear(self) -> None: ...

class ShapeFix_FreeBounds:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, shape: TopoDS_Shape, sewtoler: float, closetoler: float, splitclosed: bool, splitopen: bool) -> None: ...
	@overload
	def __init__(self, shape: TopoDS_Shape, closetoler: float, splitclosed: bool, splitopen: bool) -> None: ...
	def GetClosedWires(self) -> TopoDS_Compound: ...
	def GetOpenWires(self) -> TopoDS_Compound: ...
	def GetShape(self) -> TopoDS_Shape: ...

class ShapeFix_IntersectionTool:
	def __init__(self, context: ShapeBuild_ReShape, preci: float, maxtol: Optional[float] = 1.0) -> None: ...
	def Context(self) -> ShapeBuild_ReShape: ...
	def CutEdge(self, edge: TopoDS_Edge, pend: float, cut: float, face: TopoDS_Face) -> Tuple[bool, bool]: ...
	def FixIntersectingWires(self, face: TopoDS_Face) -> bool: ...
	def FixSelfIntersectWire(self, sewd: ShapeExtend_WireData, face: TopoDS_Face) -> Tuple[bool, int, int, int]: ...
	def SplitEdge(self, edge: TopoDS_Edge, param: float, vert: TopoDS_Vertex, face: TopoDS_Face, newE1: TopoDS_Edge, newE2: TopoDS_Edge, preci: float) -> bool: ...

class ShapeFix_Root(Standard_Transient):
	def __init__(self) -> None: ...
	def Context(self) -> ShapeBuild_ReShape: ...
	def LimitTolerance(self, toler: float) -> float: ...
	def MaxTolerance(self) -> float: ...
	def MinTolerance(self) -> float: ...
	def MsgRegistrator(self) -> ShapeExtend_BasicMsgRegistrator: ...
	def Precision(self) -> float: ...
	@overload
	def SendFail(self, shape: TopoDS_Shape, message: Message_Msg) -> None: ...
	@overload
	def SendFail(self, message: Message_Msg) -> None: ...
	@overload
	def SendMsg(self, shape: TopoDS_Shape, message: Message_Msg, gravity: Optional[Message_Gravity] = Message_Info) -> None: ...
	@overload
	def SendMsg(self, message: Message_Msg, gravity: Optional[Message_Gravity] = Message_Info) -> None: ...
	@overload
	def SendWarning(self, shape: TopoDS_Shape, message: Message_Msg) -> None: ...
	@overload
	def SendWarning(self, message: Message_Msg) -> None: ...
	def Set(self, Root: ShapeFix_Root) -> None: ...
	def SetContext(self, context: ShapeBuild_ReShape) -> None: ...
	def SetMaxTolerance(self, maxtol: float) -> None: ...
	def SetMinTolerance(self, mintol: float) -> None: ...
	def SetMsgRegistrator(self, msgreg: ShapeExtend_BasicMsgRegistrator) -> None: ...
	def SetPrecision(self, preci: float) -> None: ...

class ShapeFix_ShapeTolerance:
	def __init__(self) -> None: ...
	def LimitTolerance(self, shape: TopoDS_Shape, tmin: float, tmax: Optional[float] = 0.0, styp: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> bool: ...
	def SetTolerance(self, shape: TopoDS_Shape, preci: float, styp: Optional[TopAbs_ShapeEnum] = TopAbs_SHAPE) -> None: ...

class ShapeFix_SplitTool:
	def __init__(self) -> None: ...
	def CutEdge(self, edge: TopoDS_Edge, pend: float, cut: float, face: TopoDS_Face) -> Tuple[bool, bool]: ...
	@overload
	def SplitEdge(self, edge: TopoDS_Edge, param: float, vert: TopoDS_Vertex, face: TopoDS_Face, newE1: TopoDS_Edge, newE2: TopoDS_Edge, tol3d: float, tol2d: float) -> bool: ...
	@overload
	def SplitEdge(self, edge: TopoDS_Edge, param1: float, param2: float, vert: TopoDS_Vertex, face: TopoDS_Face, newE1: TopoDS_Edge, newE2: TopoDS_Edge, tol3d: float, tol2d: float) -> bool: ...
	@overload
	def SplitEdge(self, edge: TopoDS_Edge, fp: float, V1: TopoDS_Vertex, lp: float, V2: TopoDS_Vertex, face: TopoDS_Face, SeqE: TopTools_SequenceOfShape, context: ShapeBuild_ReShape, tol3d: float, tol2d: float) -> Tuple[bool, int]: ...

class ShapeFix_WireVertex:
	def __init__(self) -> None: ...
	def Analyzer(self) -> ShapeAnalysis_WireVertex: ...
	def Fix(self) -> int: ...
	def FixSame(self) -> int: ...
	@overload
	def Init(self, wire: TopoDS_Wire, preci: float) -> None: ...
	@overload
	def Init(self, sbwd: ShapeExtend_WireData, preci: float) -> None: ...
	@overload
	def Init(self, sawv: ShapeAnalysis_WireVertex) -> None: ...
	def Wire(self) -> TopoDS_Wire: ...
	def WireData(self) -> ShapeExtend_WireData: ...

class ShapeFix_ComposeShell(ShapeFix_Root):
	def __init__(self) -> None: ...
	def GetClosedMode(self) -> bool: ...
	def SetClosedMode(self, value: bool) -> None: ...
	def DispatchWires(self, faces: TopTools_SequenceOfShape, wires: ShapeFix_SequenceOfWireSegment) -> None: ...
	def GetTransferParamTool(self) -> ShapeAnalysis_TransferParameters: ...
	def Init(self, Grid: ShapeExtend_CompositeSurface, L: TopLoc_Location, Face: TopoDS_Face, Prec: float) -> None: ...
	def Perform(self) -> bool: ...
	def Result(self) -> TopoDS_Shape: ...
	def SetTransferParamTool(self, TransferParam: ShapeAnalysis_TransferParameters) -> None: ...
	def SplitEdges(self) -> None: ...
	def Status(self, status: ShapeExtend_Status) -> bool: ...

class ShapeFix_Face(ShapeFix_Root):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, face: TopoDS_Face) -> None: ...
	def Add(self, wire: TopoDS_Wire) -> None: ...
	def GetAutoCorrectPrecisionMode(self) -> int: ...
	def SetAutoCorrectPrecisionMode(self, value: int) -> None: ...
	def ClearModes(self) -> None: ...
	def Face(self) -> TopoDS_Face: ...
	def FixAddNaturalBound(self) -> bool: ...
	def GetFixAddNaturalBoundMode(self) -> int: ...
	def SetFixAddNaturalBoundMode(self, value: int) -> None: ...
	def FixIntersectingWires(self) -> bool: ...
	def GetFixIntersectingWiresMode(self) -> int: ...
	def SetFixIntersectingWiresMode(self, value: int) -> None: ...
	def FixLoopWire(self, aResWires: TopTools_SequenceOfShape) -> bool: ...
	def GetFixLoopWiresMode(self) -> int: ...
	def SetFixLoopWiresMode(self, value: int) -> None: ...
	def FixMissingSeam(self) -> bool: ...
	def GetFixMissingSeamMode(self) -> int: ...
	def SetFixMissingSeamMode(self, value: int) -> None: ...
	@overload
	def FixOrientation(self) -> bool: ...
	@overload
	def FixOrientation(self, MapWires: TopTools_DataMapOfShapeListOfShape) -> bool: ...
	def GetFixOrientationMode(self) -> int: ...
	def SetFixOrientationMode(self, value: int) -> None: ...
	def FixPeriodicDegenerated(self) -> bool: ...
	def GetFixPeriodicDegeneratedMode(self) -> int: ...
	def SetFixPeriodicDegeneratedMode(self, value: int) -> None: ...
	def FixSmallAreaWire(self, theIsRemoveSmallFace: bool) -> bool: ...
	def GetFixSmallAreaWireMode(self) -> int: ...
	def SetFixSmallAreaWireMode(self, value: int) -> None: ...
	def FixSplitFace(self, MapWires: TopTools_DataMapOfShapeListOfShape) -> bool: ...
	def GetFixSplitFaceMode(self) -> int: ...
	def SetFixSplitFaceMode(self, value: int) -> None: ...
	def GetFixWireMode(self) -> int: ...
	def SetFixWireMode(self, value: int) -> None: ...
	def FixWireTool(self) -> ShapeFix_Wire: ...
	def FixWiresTwoCoincEdges(self) -> bool: ...
	@overload
	def Init(self, face: TopoDS_Face) -> None: ...
	@overload
	def Init(self, surf: Geom_Surface, preci: float, fwd: Optional[bool] = True) -> None: ...
	@overload
	def Init(self, surf: ShapeAnalysis_Surface, preci: float, fwd: Optional[bool] = True) -> None: ...
	def Perform(self) -> bool: ...
	def GetRemoveSmallAreaFaceMode(self) -> int: ...
	def SetRemoveSmallAreaFaceMode(self, value: int) -> None: ...
	def Result(self) -> TopoDS_Shape: ...
	def SetMaxTolerance(self, maxtol: float) -> None: ...
	def SetMinTolerance(self, mintol: float) -> None: ...
	def SetMsgRegistrator(self, msgreg: ShapeExtend_BasicMsgRegistrator) -> None: ...
	def SetPrecision(self, preci: float) -> None: ...
	def Status(self, status: ShapeExtend_Status) -> bool: ...

class ShapeFix_FixSmallFace(ShapeFix_Root):
	def __init__(self) -> None: ...
	def ComputeSharedEdgeForStripFace(self, F: TopoDS_Face, E1: TopoDS_Edge, E2: TopoDS_Edge, F1: TopoDS_Face, tol: float) -> TopoDS_Edge: ...
	def FixFace(self, F: TopoDS_Face) -> TopoDS_Face: ...
	def FixPinFace(self, F: TopoDS_Face) -> bool: ...
	def FixShape(self) -> TopoDS_Shape: ...
	def FixSplitFace(self, S: TopoDS_Shape) -> TopoDS_Shape: ...
	def FixSpotFace(self) -> TopoDS_Shape: ...
	def FixStripFace(self, wasdone: Optional[bool] = False) -> TopoDS_Shape: ...
	def Init(self, S: TopoDS_Shape) -> None: ...
	def Perform(self) -> None: ...
	def RemoveFacesInCaseOfSpot(self, F: TopoDS_Face) -> bool: ...
	def RemoveFacesInCaseOfStrip(self, F: TopoDS_Face) -> bool: ...
	def ReplaceInCaseOfStrip(self, F: TopoDS_Face, E1: TopoDS_Edge, E2: TopoDS_Edge, tol: float) -> bool: ...
	def ReplaceVerticesInCaseOfSpot(self, F: TopoDS_Face, tol: float) -> bool: ...
	def Shape(self) -> TopoDS_Shape: ...
	def SplitOneFace(self, F: TopoDS_Face, theSplittedFaces: TopoDS_Compound) -> bool: ...

class ShapeFix_FixSmallSolid(ShapeFix_Root):
	def __init__(self) -> None: ...
	def Merge(self, theShape: TopoDS_Shape, theContext: ShapeBuild_ReShape) -> TopoDS_Shape: ...
	def Remove(self, theShape: TopoDS_Shape, theContext: ShapeBuild_ReShape) -> TopoDS_Shape: ...
	def SetFixMode(self, theMode: int) -> None: ...
	def SetVolumeThreshold(self, theThreshold: Optional[float] = -1.0) -> None: ...
	def SetWidthFactorThreshold(self, theThreshold: Optional[float] = -1.0) -> None: ...

class ShapeFix_Shape(ShapeFix_Root):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, shape: TopoDS_Shape) -> None: ...
	def FixEdgeTool(self) -> ShapeFix_Edge: ...
	def FixFaceTool(self) -> ShapeFix_Face: ...
	def GetFixFreeFaceMode(self) -> int: ...
	def SetFixFreeFaceMode(self, value: int) -> None: ...
	def GetFixFreeShellMode(self) -> int: ...
	def SetFixFreeShellMode(self, value: int) -> None: ...
	def GetFixFreeWireMode(self) -> int: ...
	def SetFixFreeWireMode(self, value: int) -> None: ...
	def GetFixSameParameterMode(self) -> int: ...
	def SetFixSameParameterMode(self, value: int) -> None: ...
	def FixShellTool(self) -> ShapeFix_Shell: ...
	def GetFixSolidMode(self) -> int: ...
	def SetFixSolidMode(self, value: int) -> None: ...
	def FixSolidTool(self) -> ShapeFix_Solid: ...
	def GetFixVertexPositionMode(self) -> int: ...
	def SetFixVertexPositionMode(self, value: int) -> None: ...
	def GetFixVertexTolMode(self) -> int: ...
	def SetFixVertexTolMode(self, value: int) -> None: ...
	def FixWireTool(self) -> ShapeFix_Wire: ...
	def Init(self, shape: TopoDS_Shape) -> None: ...
	def Perform(self, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> bool: ...
	def SetMaxTolerance(self, maxtol: float) -> None: ...
	def SetMinTolerance(self, mintol: float) -> None: ...
	def SetMsgRegistrator(self, msgreg: ShapeExtend_BasicMsgRegistrator) -> None: ...
	def SetPrecision(self, preci: float) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...
	def Status(self, status: ShapeExtend_Status) -> bool: ...

class ShapeFix_Shell(ShapeFix_Root):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, shape: TopoDS_Shell) -> None: ...
	def ErrorFaces(self) -> TopoDS_Compound: ...
	def GetFixFaceMode(self) -> int: ...
	def SetFixFaceMode(self, value: int) -> None: ...
	def FixFaceOrientation(self, shell: TopoDS_Shell, isAccountMultiConex: Optional[bool] = True, NonManifold: Optional[bool] = False) -> bool: ...
	def FixFaceTool(self) -> ShapeFix_Face: ...
	def GetFixOrientationMode(self) -> int: ...
	def SetFixOrientationMode(self, value: int) -> None: ...
	def Init(self, shell: TopoDS_Shell) -> None: ...
	def NbShells(self) -> int: ...
	def Perform(self, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> bool: ...
	def SetMaxTolerance(self, maxtol: float) -> None: ...
	def SetMinTolerance(self, mintol: float) -> None: ...
	def SetMsgRegistrator(self, msgreg: ShapeExtend_BasicMsgRegistrator) -> None: ...
	def SetNonManifoldFlag(self, isNonManifold: bool) -> None: ...
	def SetPrecision(self, preci: float) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...
	def Shell(self) -> TopoDS_Shell: ...
	def Status(self, status: ShapeExtend_Status) -> bool: ...

class ShapeFix_Solid(ShapeFix_Root):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, solid: TopoDS_Solid) -> None: ...
	def GetCreateOpenSolidMode(self) -> bool: ...
	def SetCreateOpenSolidMode(self, value: bool) -> None: ...
	def GetFixShellMode(self) -> int: ...
	def SetFixShellMode(self, value: int) -> None: ...
	def GetFixShellOrientationMode(self) -> int: ...
	def SetFixShellOrientationMode(self, value: int) -> None: ...
	def FixShellTool(self) -> ShapeFix_Shell: ...
	def Init(self, solid: TopoDS_Solid) -> None: ...
	def Perform(self, theProgress: Optional[Message_ProgressRange] = Message_ProgressRange()) -> bool: ...
	def SetMaxTolerance(self, maxtol: float) -> None: ...
	def SetMinTolerance(self, mintol: float) -> None: ...
	def SetMsgRegistrator(self, msgreg: ShapeExtend_BasicMsgRegistrator) -> None: ...
	def SetPrecision(self, preci: float) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...
	def Solid(self) -> TopoDS_Shape: ...
	def SolidFromShell(self, shell: TopoDS_Shell) -> TopoDS_Solid: ...
	def Status(self, status: ShapeExtend_Status) -> bool: ...

class ShapeFix_SplitCommonVertex(ShapeFix_Root):
	def __init__(self) -> None: ...
	def Init(self, S: TopoDS_Shape) -> None: ...
	def Perform(self) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...

class ShapeFix_Wire(ShapeFix_Root):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, wire: TopoDS_Wire, face: TopoDS_Face, prec: float) -> None: ...
	def Analyzer(self) -> ShapeAnalysis_Wire: ...
	def ClearModes(self) -> None: ...
	def ClearStatuses(self) -> None: ...
	def GetClosedWireMode(self) -> bool: ...
	def SetClosedWireMode(self, value: bool) -> None: ...
	def Face(self) -> TopoDS_Face: ...
	def GetFixAddCurve3dMode(self) -> int: ...
	def SetFixAddCurve3dMode(self, value: int) -> None: ...
	def GetFixAddPCurveMode(self) -> int: ...
	def SetFixAddPCurveMode(self, value: int) -> None: ...
	def FixClosed(self, prec: Optional[float] = -1.0) -> bool: ...
	@overload
	def FixConnected(self, prec: Optional[float] = -1.0) -> bool: ...
	@overload
	def FixConnected(self, num: int, prec: float) -> bool: ...
	def GetFixConnectedMode(self) -> int: ...
	def SetFixConnectedMode(self, value: int) -> None: ...
	@overload
	def FixDegenerated(self) -> bool: ...
	@overload
	def FixDegenerated(self, num: int) -> bool: ...
	def GetFixDegeneratedMode(self) -> int: ...
	def SetFixDegeneratedMode(self, value: int) -> None: ...
	def FixEdgeCurves(self) -> bool: ...
	def GetFixEdgeCurvesMode(self) -> int: ...
	def SetFixEdgeCurvesMode(self, value: int) -> None: ...
	def FixEdgeTool(self) -> ShapeFix_Edge: ...
	def FixGap2d(self, num: int, convert: Optional[bool] = False) -> bool: ...
	def FixGap3d(self, num: int, convert: Optional[bool] = False) -> bool: ...
	def FixGaps2d(self) -> bool: ...
	def GetFixGaps2dMode(self) -> int: ...
	def SetFixGaps2dMode(self, value: int) -> None: ...
	def FixGaps3d(self) -> bool: ...
	def GetFixGaps3dMode(self) -> int: ...
	def SetFixGaps3dMode(self, value: int) -> None: ...
	def GetFixGapsByRangesMode(self) -> bool: ...
	def SetFixGapsByRangesMode(self, value: bool) -> None: ...
	def GetFixIntersectingEdgesMode(self) -> int: ...
	def SetFixIntersectingEdgesMode(self, value: int) -> None: ...
	@overload
	def FixLacking(self, force: Optional[bool] = False) -> bool: ...
	@overload
	def FixLacking(self, num: int, force: Optional[bool] = False) -> bool: ...
	def GetFixLackingMode(self) -> int: ...
	def SetFixLackingMode(self, value: int) -> None: ...
	def GetFixNonAdjacentIntersectingEdgesMode(self) -> int: ...
	def SetFixNonAdjacentIntersectingEdgesMode(self, value: int) -> None: ...
	def FixNotchedEdges(self) -> bool: ...
	def GetFixNotchedEdgesMode(self) -> int: ...
	def SetFixNotchedEdgesMode(self, value: int) -> None: ...
	def GetFixRemoveCurve3dMode(self) -> int: ...
	def SetFixRemoveCurve3dMode(self, value: int) -> None: ...
	def GetFixRemovePCurveMode(self) -> int: ...
	def SetFixRemovePCurveMode(self, value: int) -> None: ...
	@overload
	def FixReorder(self) -> bool: ...
	@overload
	def FixReorder(self, wi: ShapeAnalysis_WireOrder) -> bool: ...
	def GetFixReorderMode(self) -> int: ...
	def SetFixReorderMode(self, value: int) -> None: ...
	def GetFixReversed2dMode(self) -> int: ...
	def SetFixReversed2dMode(self, value: int) -> None: ...
	def GetFixSameParameterMode(self) -> int: ...
	def SetFixSameParameterMode(self, value: int) -> None: ...
	def FixSeam(self, num: int) -> bool: ...
	def GetFixSeamMode(self) -> int: ...
	def SetFixSeamMode(self, value: int) -> None: ...
	def GetFixSelfIntersectingEdgeMode(self) -> int: ...
	def SetFixSelfIntersectingEdgeMode(self, value: int) -> None: ...
	def FixSelfIntersection(self) -> bool: ...
	def GetFixSelfIntersectionMode(self) -> int: ...
	def SetFixSelfIntersectionMode(self, value: int) -> None: ...
	def FixShifted(self) -> bool: ...
	def GetFixShiftedMode(self) -> int: ...
	def SetFixShiftedMode(self, value: int) -> None: ...
	@overload
	def FixSmall(self, lockvtx: bool, precsmall: Optional[float] = 0.0) -> int: ...
	@overload
	def FixSmall(self, num: int, lockvtx: bool, precsmall: float) -> bool: ...
	def GetFixSmallMode(self) -> int: ...
	def SetFixSmallMode(self, value: int) -> None: ...
	def GetFixTailMode(self) -> int: ...
	def SetFixTailMode(self, value: int) -> None: ...
	def FixTails(self) -> bool: ...
	def GetFixVertexToleranceMode(self) -> int: ...
	def SetFixVertexToleranceMode(self, value: int) -> None: ...
	@overload
	def Init(self, wire: TopoDS_Wire, face: TopoDS_Face, prec: float) -> None: ...
	@overload
	def Init(self, saw: ShapeAnalysis_Wire) -> None: ...
	def IsLoaded(self) -> bool: ...
	def IsReady(self) -> bool: ...
	def LastFixStatus(self, status: ShapeExtend_Status) -> bool: ...
	@overload
	def Load(self, wire: TopoDS_Wire) -> None: ...
	@overload
	def Load(self, sbwd: ShapeExtend_WireData) -> None: ...
	def GetModifyGeometryMode(self) -> bool: ...
	def SetModifyGeometryMode(self, value: bool) -> None: ...
	def GetModifyRemoveLoopMode(self) -> int: ...
	def SetModifyRemoveLoopMode(self, value: int) -> None: ...
	def GetModifyTopologyMode(self) -> bool: ...
	def SetModifyTopologyMode(self, value: bool) -> None: ...
	def NbEdges(self) -> int: ...
	def Perform(self) -> bool: ...
	def GetPreferencePCurveMode(self) -> bool: ...
	def SetPreferencePCurveMode(self, value: bool) -> None: ...
	def SetFace(self, face: TopoDS_Face) -> None: ...
	def SetMaxTailAngle(self, theMaxTailAngle: float) -> None: ...
	def SetMaxTailWidth(self, theMaxTailWidth: float) -> None: ...
	def SetPrecision(self, prec: float) -> None: ...
	@overload
	def SetSurface(self, surf: Geom_Surface) -> None: ...
	@overload
	def SetSurface(self, surf: Geom_Surface, loc: TopLoc_Location) -> None: ...
	def StatusClosed(self, status: ShapeExtend_Status) -> bool: ...
	def StatusConnected(self, status: ShapeExtend_Status) -> bool: ...
	def StatusDegenerated(self, status: ShapeExtend_Status) -> bool: ...
	def StatusEdgeCurves(self, status: ShapeExtend_Status) -> bool: ...
	def StatusFixTails(self, status: ShapeExtend_Status) -> bool: ...
	def StatusGaps2d(self, status: ShapeExtend_Status) -> bool: ...
	def StatusGaps3d(self, status: ShapeExtend_Status) -> bool: ...
	def StatusLacking(self, status: ShapeExtend_Status) -> bool: ...
	def StatusNotches(self, status: ShapeExtend_Status) -> bool: ...
	def StatusRemovedSegment(self) -> bool: ...
	def StatusReorder(self, status: ShapeExtend_Status) -> bool: ...
	def StatusSelfIntersection(self, status: ShapeExtend_Status) -> bool: ...
	def StatusSmall(self, status: ShapeExtend_Status) -> bool: ...
	def Wire(self) -> TopoDS_Wire: ...
	def WireAPIMake(self) -> TopoDS_Wire: ...
	def WireData(self) -> ShapeExtend_WireData: ...

class ShapeFix_Wireframe(ShapeFix_Root):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, shape: TopoDS_Shape) -> None: ...
	def CheckSmallEdges(self, theSmallEdges: TopTools_MapOfShape, theEdgeToFaces: TopTools_DataMapOfShapeListOfShape, theFaceWithSmall: TopTools_DataMapOfShapeListOfShape, theMultyEdges: TopTools_MapOfShape) -> bool: ...
	def ClearStatuses(self) -> None: ...
	def FixSmallEdges(self) -> bool: ...
	def FixWireGaps(self) -> bool: ...
	def LimitAngle(self) -> float: ...
	def Load(self, shape: TopoDS_Shape) -> None: ...
	def MergeSmallEdges(self, theSmallEdges: TopTools_MapOfShape, theEdgeToFaces: TopTools_DataMapOfShapeListOfShape, theFaceWithSmall: TopTools_DataMapOfShapeListOfShape, theMultyEdges: TopTools_MapOfShape, theModeDrop: Optional[bool] = False, theLimitAngle: Optional[float] = -1) -> bool: ...
	def GetModeDropSmallEdges(self) -> bool: ...
	def SetModeDropSmallEdges(self, value: bool) -> None: ...
	def SetLimitAngle(self, theLimitAngle: float) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...
	def StatusSmallEdges(self, status: ShapeExtend_Status) -> bool: ...
	def StatusWireGaps(self, status: ShapeExtend_Status) -> bool: ...

#classnotwrapped
class ShapeFix_WireSegment: ...

# harray1 classes
# harray2 classes
# hsequence classes

shapefix_EncodeRegularity = shapefix.EncodeRegularity
shapefix_FixVertexPosition = shapefix.FixVertexPosition
shapefix_LeastEdgeSize = shapefix.LeastEdgeSize
shapefix_RemoveSmallEdges = shapefix.RemoveSmallEdges
shapefix_SameParameter = shapefix.SameParameter



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColStd import *
from OCC.Core.Adaptor3d import *
from OCC.Core.Adaptor2d import *
from OCC.Core.GeomAbs import *
from OCC.Core.Geom2d import *
from OCC.Core.Geom import *
from OCC.Core.AppCont import *
from OCC.Core.AppParCurves import *
from OCC.Core.TColgp import *
from OCC.Core.gp import *


class Approx_Array1OfAdHSurface:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Approx_Array1OfGTrsf2d:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> gp_GTrsf2d: ...
    def __setitem__(self, index: int, value: gp_GTrsf2d) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[gp_GTrsf2d]: ...
    def next(self) -> gp_GTrsf2d: ...
    __next__ = next
    def Init(self, theValue: gp_GTrsf2d) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> gp_GTrsf2d: ...
    def Last(self) -> gp_GTrsf2d: ...
    def Value(self, theIndex: int) -> gp_GTrsf2d: ...
    def SetValue(self, theIndex: int, theValue: gp_GTrsf2d) -> None: ...

class Approx_SequenceOfHArray1OfReal:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class Approx_Status(IntEnum):
	Approx_PointsAdded: int = ...
	Approx_NoPointsAdded: int = ...
	Approx_NoApproximation: int = ...
Approx_PointsAdded = Approx_Status.Approx_PointsAdded
Approx_NoPointsAdded = Approx_Status.Approx_NoPointsAdded
Approx_NoApproximation = Approx_Status.Approx_NoApproximation

class Approx_ParametrizationType(IntEnum):
	Approx_ChordLength: int = ...
	Approx_Centripetal: int = ...
	Approx_IsoParametric: int = ...
Approx_ChordLength = Approx_ParametrizationType.Approx_ChordLength
Approx_Centripetal = Approx_ParametrizationType.Approx_Centripetal
Approx_IsoParametric = Approx_ParametrizationType.Approx_IsoParametric

class Approx_Curve2d:
	def __init__(self, C2D: Adaptor2d_HCurve2d, First: float, Last: float, TolU: float, TolV: float, Continuity: GeomAbs_Shape, MaxDegree: int, MaxSegments: int) -> None: ...
	def Curve(self) -> Geom2d_BSplineCurve: ...
	def HasResult(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def MaxError2dU(self) -> float: ...
	def MaxError2dV(self) -> float: ...

class Approx_Curve3d:
	def __init__(self, Curve: Adaptor3d_HCurve, Tol3d: float, Order: GeomAbs_Shape, MaxSegments: int, MaxDegree: int) -> None: ...
	def Curve(self) -> Geom_BSplineCurve: ...
	def HasResult(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def MaxError(self) -> float: ...

class Approx_CurveOnSurface:
	@overload
	def __init__(self, C2D: Adaptor2d_HCurve2d, Surf: Adaptor3d_HSurface, First: float, Last: float, Tol: float, Continuity: GeomAbs_Shape, MaxDegree: int, MaxSegments: int, Only3d: Optional[bool] = False, Only2d: Optional[bool] = False) -> None: ...
	@overload
	def __init__(self, theC2D: Adaptor2d_HCurve2d, theSurf: Adaptor3d_HSurface, theFirst: float, theLast: float, theTol: float) -> None: ...
	def Curve2d(self) -> Geom2d_BSplineCurve: ...
	def Curve3d(self) -> Geom_BSplineCurve: ...
	def HasResult(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def MaxError2dU(self) -> float: ...
	def MaxError2dV(self) -> float: ...
	def MaxError3d(self) -> float: ...
	def Perform(self, theMaxSegments: int, theMaxDegree: int, theContinuity: GeomAbs_Shape, theOnly3d: Optional[bool] = False, theOnly2d: Optional[bool] = False) -> None: ...

class Approx_CurvilinearParameter:
	@overload
	def __init__(self, C3D: Adaptor3d_HCurve, Tol: float, Order: GeomAbs_Shape, MaxDegree: int, MaxSegments: int) -> None: ...
	@overload
	def __init__(self, C2D: Adaptor2d_HCurve2d, Surf: Adaptor3d_HSurface, Tol: float, Order: GeomAbs_Shape, MaxDegree: int, MaxSegments: int) -> None: ...
	@overload
	def __init__(self, C2D1: Adaptor2d_HCurve2d, Surf1: Adaptor3d_HSurface, C2D2: Adaptor2d_HCurve2d, Surf2: Adaptor3d_HSurface, Tol: float, Order: GeomAbs_Shape, MaxDegree: int, MaxSegments: int) -> None: ...
	def Curve2d1(self) -> Geom2d_BSplineCurve: ...
	def Curve2d2(self) -> Geom2d_BSplineCurve: ...
	def Curve3d(self) -> Geom_BSplineCurve: ...
	def HasResult(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def MaxError2d1(self) -> float: ...
	def MaxError2d2(self) -> float: ...
	def MaxError3d(self) -> float: ...

class Approx_CurvlinFunc(Standard_Transient):
	@overload
	def __init__(self, C: Adaptor3d_HCurve, Tol: float) -> None: ...
	@overload
	def __init__(self, C2D: Adaptor2d_HCurve2d, S: Adaptor3d_HSurface, Tol: float) -> None: ...
	@overload
	def __init__(self, C2D1: Adaptor2d_HCurve2d, C2D2: Adaptor2d_HCurve2d, S1: Adaptor3d_HSurface, S2: Adaptor3d_HSurface, Tol: float) -> None: ...
	def EvalCase1(self, S: float, Order: int, Result: TColStd_Array1OfReal) -> bool: ...
	def EvalCase2(self, S: float, Order: int, Result: TColStd_Array1OfReal) -> bool: ...
	def EvalCase3(self, S: float, Order: int, Result: TColStd_Array1OfReal) -> bool: ...
	def FirstParameter(self) -> float: ...
	def GetLength(self) -> float: ...
	def GetSParameter(self, U: float) -> float: ...
	def GetUParameter(self, C: Adaptor3d_Curve, S: float, NumberOfCurve: int) -> float: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def LastParameter(self) -> float: ...
	@overload
	def Length(self) -> None: ...
	@overload
	def Length(self, C: Adaptor3d_Curve, FirstU: float, LasrU: float) -> float: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def SetTol(self, Tol: float) -> None: ...
	def Trim(self, First: float, Last: float, Tol: float) -> None: ...

class Approx_FitAndDivide:
	@overload
	def __init__(self, Line: AppCont_Function, degreemin: Optional[int] = 3, degreemax: Optional[int] = 8, Tolerance3d: Optional[float] = 1.0e-5, Tolerance2d: Optional[float] = 1.0e-5, cutting: Optional[bool] = False, FirstC: Optional[AppParCurves_Constraint] = AppParCurves_TangencyPoint, LastC: Optional[AppParCurves_Constraint] = AppParCurves_TangencyPoint) -> None: ...
	@overload
	def __init__(self, degreemin: Optional[int] = 3, degreemax: Optional[int] = 8, Tolerance3d: Optional[float] = 1.0e-05, Tolerance2d: Optional[float] = 1.0e-05, cutting: Optional[bool] = False, FirstC: Optional[AppParCurves_Constraint] = AppParCurves_TangencyPoint, LastC: Optional[AppParCurves_Constraint] = AppParCurves_TangencyPoint) -> None: ...
	def Error(self, Index: int) -> Tuple[float, float]: ...
	def IsAllApproximated(self) -> bool: ...
	def IsToleranceReached(self) -> bool: ...
	def NbMultiCurves(self) -> int: ...
	def Parameters(self, Index: int) -> Tuple[float, float]: ...
	def Perform(self, Line: AppCont_Function) -> None: ...
	def SetConstraints(self, FirstC: AppParCurves_Constraint, LastC: AppParCurves_Constraint) -> None: ...
	def SetDegrees(self, degreemin: int, degreemax: int) -> None: ...
	def SetHangChecking(self, theHangChecking: bool) -> None: ...
	def SetInvOrder(self, theInvOrder: bool) -> None: ...
	def SetMaxSegments(self, theMaxSegments: int) -> None: ...
	def SetTolerances(self, Tolerance3d: float, Tolerance2d: float) -> None: ...
	def Value(self, Index: Optional[int] = 1) -> AppParCurves_MultiCurve: ...

class Approx_FitAndDivide2d:
	@overload
	def __init__(self, Line: AppCont_Function, degreemin: Optional[int] = 3, degreemax: Optional[int] = 8, Tolerance3d: Optional[float] = 1.0e-5, Tolerance2d: Optional[float] = 1.0e-5, cutting: Optional[bool] = False, FirstC: Optional[AppParCurves_Constraint] = AppParCurves_TangencyPoint, LastC: Optional[AppParCurves_Constraint] = AppParCurves_TangencyPoint) -> None: ...
	@overload
	def __init__(self, degreemin: Optional[int] = 3, degreemax: Optional[int] = 8, Tolerance3d: Optional[float] = 1.0e-05, Tolerance2d: Optional[float] = 1.0e-05, cutting: Optional[bool] = False, FirstC: Optional[AppParCurves_Constraint] = AppParCurves_TangencyPoint, LastC: Optional[AppParCurves_Constraint] = AppParCurves_TangencyPoint) -> None: ...
	def Error(self, Index: int) -> Tuple[float, float]: ...
	def IsAllApproximated(self) -> bool: ...
	def IsToleranceReached(self) -> bool: ...
	def NbMultiCurves(self) -> int: ...
	def Parameters(self, Index: int) -> Tuple[float, float]: ...
	def Perform(self, Line: AppCont_Function) -> None: ...
	def SetConstraints(self, FirstC: AppParCurves_Constraint, LastC: AppParCurves_Constraint) -> None: ...
	def SetDegrees(self, degreemin: int, degreemax: int) -> None: ...
	def SetHangChecking(self, theHangChecking: bool) -> None: ...
	def SetInvOrder(self, theInvOrder: bool) -> None: ...
	def SetMaxSegments(self, theMaxSegments: int) -> None: ...
	def SetTolerances(self, Tolerance3d: float, Tolerance2d: float) -> None: ...
	def Value(self, Index: Optional[int] = 1) -> AppParCurves_MultiCurve: ...

class Approx_MCurvesToBSpCurve:
	def __init__(self) -> None: ...
	def Append(self, MC: AppParCurves_MultiCurve) -> None: ...
	def ChangeValue(self) -> AppParCurves_MultiBSpCurve: ...
	@overload
	def Perform(self) -> None: ...
	@overload
	def Perform(self, TheSeq: AppParCurves_SequenceOfMultiCurve) -> None: ...
	def Reset(self) -> None: ...
	def Value(self) -> AppParCurves_MultiBSpCurve: ...

class Approx_SameParameter:
	@overload
	def __init__(self, C3D: Geom_Curve, C2D: Geom2d_Curve, S: Geom_Surface, Tol: float) -> None: ...
	@overload
	def __init__(self, C3D: Adaptor3d_HCurve, C2D: Geom2d_Curve, S: Adaptor3d_HSurface, Tol: float) -> None: ...
	@overload
	def __init__(self, C3D: Adaptor3d_HCurve, C2D: Adaptor2d_HCurve2d, S: Adaptor3d_HSurface, Tol: float) -> None: ...
	def Curve2d(self) -> Geom2d_Curve: ...
	def IsDone(self) -> bool: ...
	def IsSameParameter(self) -> bool: ...
	def TolReached(self) -> float: ...

class Approx_SweepApproximation:
	def __init__(self, Func: Approx_SweepFunction) -> None: ...
	def Average2dError(self, Index: int) -> float: ...
	def AverageErrorOnSurf(self) -> float: ...
	def Curve2d(self, Index: int, TPoles: TColgp_Array1OfPnt2d, TKnots: TColStd_Array1OfReal, TMults: TColStd_Array1OfInteger) -> None: ...
	def Curve2dPoles(self, Index: int) -> TColgp_Array1OfPnt2d: ...
	def Curves2dDegree(self) -> int: ...
	def Curves2dKnots(self) -> TColStd_Array1OfReal: ...
	def Curves2dMults(self) -> TColStd_Array1OfInteger: ...
	def Curves2dShape(self) -> Tuple[int, int, int]: ...
	def Eval(self, Parameter: float, DerivativeRequest: int, First: float, Last: float) -> Tuple[int, float]: ...
	def IsDone(self) -> bool: ...
	def Max2dError(self, Index: int) -> float: ...
	def MaxErrorOnSurf(self) -> float: ...
	def NbCurves2d(self) -> int: ...
	def Perform(self, First: float, Last: float, Tol3d: float, BoundTol: float, Tol2d: float, TolAngular: float, Continuity: Optional[GeomAbs_Shape] = GeomAbs_C0, Degmax: Optional[int] = 11, Segmax: Optional[int] = 50) -> None: ...
	def SurfPoles(self) -> TColgp_Array2OfPnt: ...
	def SurfShape(self) -> Tuple[int, int, int, int, int, int]: ...
	def SurfUKnots(self) -> TColStd_Array1OfReal: ...
	def SurfUMults(self) -> TColStd_Array1OfInteger: ...
	def SurfVKnots(self) -> TColStd_Array1OfReal: ...
	def SurfVMults(self) -> TColStd_Array1OfInteger: ...
	def SurfWeights(self) -> TColStd_Array2OfReal: ...
	def Surface(self, TPoles: TColgp_Array2OfPnt, TWeights: TColStd_Array2OfReal, TUKnots: TColStd_Array1OfReal, TVKnots: TColStd_Array1OfReal, TUMults: TColStd_Array1OfInteger, TVMults: TColStd_Array1OfInteger) -> None: ...
	def TolCurveOnSurf(self, Index: int) -> float: ...
	def UDegree(self) -> int: ...
	def VDegree(self) -> int: ...

class Approx_SweepFunction(Standard_Transient):
	def BarycentreOfSurf(self) -> gp_Pnt: ...
	def D0(self, Param: float, First: float, Last: float, Poles: TColgp_Array1OfPnt, Poles2d: TColgp_Array1OfPnt2d, Weigths: TColStd_Array1OfReal) -> bool: ...
	def D1(self, Param: float, First: float, Last: float, Poles: TColgp_Array1OfPnt, DPoles: TColgp_Array1OfVec, Poles2d: TColgp_Array1OfPnt2d, DPoles2d: TColgp_Array1OfVec2d, Weigths: TColStd_Array1OfReal, DWeigths: TColStd_Array1OfReal) -> bool: ...
	def D2(self, Param: float, First: float, Last: float, Poles: TColgp_Array1OfPnt, DPoles: TColgp_Array1OfVec, D2Poles: TColgp_Array1OfVec, Poles2d: TColgp_Array1OfPnt2d, DPoles2d: TColgp_Array1OfVec2d, D2Poles2d: TColgp_Array1OfVec2d, Weigths: TColStd_Array1OfReal, DWeigths: TColStd_Array1OfReal, D2Weigths: TColStd_Array1OfReal) -> bool: ...
	def GetMinimalWeight(self, Weigths: TColStd_Array1OfReal) -> None: ...
	def GetTolerance(self, BoundTol: float, SurfTol: float, AngleTol: float, Tol3d: TColStd_Array1OfReal) -> None: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsRational(self) -> bool: ...
	def Knots(self, TKnots: TColStd_Array1OfReal) -> None: ...
	def MaximalSection(self) -> float: ...
	def Mults(self, TMults: TColStd_Array1OfInteger) -> None: ...
	def Nb2dCurves(self) -> int: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def Resolution(self, Index: int, Tol: float) -> Tuple[float, float]: ...
	def SectionShape(self) -> Tuple[int, int, int]: ...
	def SetInterval(self, First: float, Last: float) -> None: ...
	def SetTolerance(self, Tol3d: float, Tol2d: float) -> None: ...

# harray1 classes

class Approx_HArray1OfGTrsf2d(Approx_Array1OfGTrsf2d, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> Approx_Array1OfGTrsf2d: ...


class Approx_HArray1OfAdHSurface(Approx_Array1OfAdHSurface, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> Approx_Array1OfAdHSurface: ...

# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.Geom2dAdaptor import *
from OCC.Core.IntRes2d import *
from OCC.Core.TopAbs import *
from OCC.Core.Geom2d import *
from OCC.Core.HatchGen import *
from OCC.Core.Geom2dInt import *


class Geom2dHatch_Classifier:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, F: Geom2dHatch_Elements, P: gp_Pnt2d, Tol: float) -> None: ...
	def Edge(self) -> Geom2dAdaptor_Curve: ...
	def EdgeParameter(self) -> float: ...
	def NoWires(self) -> bool: ...
	def Perform(self, F: Geom2dHatch_Elements, P: gp_Pnt2d, Tol: float) -> None: ...
	def Position(self) -> IntRes2d_Position: ...
	def Rejected(self) -> bool: ...
	def State(self) -> TopAbs_State: ...

class Geom2dHatch_Element:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Curve: Geom2dAdaptor_Curve, Orientation: Optional[TopAbs_Orientation] = TopAbs_FORWARD) -> None: ...
	def ChangeCurve(self) -> Geom2dAdaptor_Curve: ...
	def Curve(self) -> Geom2dAdaptor_Curve: ...
	@overload
	def Orientation(self, Orientation: TopAbs_Orientation) -> None: ...
	@overload
	def Orientation(self) -> TopAbs_Orientation: ...

class Geom2dHatch_Elements:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Other: Geom2dHatch_Elements) -> None: ...
	def Bind(self, K: int, I: Geom2dHatch_Element) -> bool: ...
	def ChangeFind(self, K: int) -> Geom2dHatch_Element: ...
	def CheckPoint(self, P: gp_Pnt2d) -> bool: ...
	def Clear(self) -> None: ...
	def CurrentEdge(self, E: Geom2dAdaptor_Curve, Or: TopAbs_Orientation) -> None: ...
	def Find(self, K: int) -> Geom2dHatch_Element: ...
	def InitEdges(self) -> None: ...
	def InitWires(self) -> None: ...
	def IsBound(self, K: int) -> bool: ...
	def MoreEdges(self) -> bool: ...
	def MoreWires(self) -> bool: ...
	def NextEdge(self) -> None: ...
	def NextWire(self) -> None: ...
	def OtherSegment(self, P: gp_Pnt2d, L: gp_Lin2d) -> Tuple[bool, float]: ...
	def Reject(self, P: gp_Pnt2d) -> bool: ...
	def RejectEdge(self, L: gp_Lin2d, Par: float) -> bool: ...
	def RejectWire(self, L: gp_Lin2d, Par: float) -> bool: ...
	def Segment(self, P: gp_Pnt2d, L: gp_Lin2d) -> Tuple[bool, float]: ...
	def UnBind(self, K: int) -> bool: ...

class Geom2dHatch_FClass2dOfClassifier:
	def __init__(self) -> None: ...
	def ClosestIntersection(self) -> int: ...
	def Compare(self, E: Geom2dAdaptor_Curve, Or: TopAbs_Orientation) -> None: ...
	def Intersector(self) -> Geom2dHatch_Intersector: ...
	def IsHeadOrEnd(self) -> bool: ...
	def Parameter(self) -> float: ...
	def Reset(self, L: gp_Lin2d, P: float, Tol: float) -> None: ...
	def State(self) -> TopAbs_State: ...

class Geom2dHatch_Hatcher:
	def __init__(self, Intersector: Geom2dHatch_Intersector, Confusion2d: float, Confusion3d: float, KeepPnt: Optional[bool] = False, KeepSeg: Optional[bool] = False) -> None: ...
	@overload
	def AddElement(self, Curve: Geom2dAdaptor_Curve, Orientation: Optional[TopAbs_Orientation] = TopAbs_FORWARD) -> int: ...
	@overload
	def AddElement(self, Curve: Geom2d_Curve, Orientation: Optional[TopAbs_Orientation] = TopAbs_FORWARD) -> int: ...
	def AddHatching(self, Curve: Geom2dAdaptor_Curve) -> int: ...
	def ChangeIntersector(self) -> Geom2dHatch_Intersector: ...
	def Clear(self) -> None: ...
	def ClrElements(self) -> None: ...
	def ClrHatchings(self) -> None: ...
	@overload
	def ComputeDomains(self) -> None: ...
	@overload
	def ComputeDomains(self, IndH: int) -> None: ...
	@overload
	def Confusion2d(self, Confusion: float) -> None: ...
	@overload
	def Confusion2d(self) -> float: ...
	@overload
	def Confusion3d(self, Confusion: float) -> None: ...
	@overload
	def Confusion3d(self) -> float: ...
	def Domain(self, IndH: int, IDom: int) -> HatchGen_Domain: ...
	def Dump(self) -> None: ...
	def ElementCurve(self, IndE: int) -> Geom2dAdaptor_Curve: ...
	def HatchingCurve(self, IndH: int) -> Geom2dAdaptor_Curve: ...
	@overload
	def Intersector(self, Intersector: Geom2dHatch_Intersector) -> None: ...
	@overload
	def Intersector(self) -> Geom2dHatch_Intersector: ...
	@overload
	def KeepPoints(self, Keep: bool) -> None: ...
	@overload
	def KeepPoints(self) -> bool: ...
	@overload
	def KeepSegments(self, Keep: bool) -> None: ...
	@overload
	def KeepSegments(self) -> bool: ...
	def NbDomains(self, IndH: int) -> int: ...
	def NbPoints(self, IndH: int) -> int: ...
	def Point(self, IndH: int, IndP: int) -> HatchGen_PointOnHatching: ...
	def RemElement(self, IndE: int) -> None: ...
	def RemHatching(self, IndH: int) -> None: ...
	def Status(self, IndH: int) -> HatchGen_ErrorStatus: ...
	@overload
	def Trim(self) -> None: ...
	@overload
	def Trim(self, Curve: Geom2dAdaptor_Curve) -> int: ...
	@overload
	def Trim(self, IndH: int) -> None: ...
	def TrimDone(self, IndH: int) -> bool: ...
	def TrimFailed(self, IndH: int) -> bool: ...

class Geom2dHatch_Hatching:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Curve: Geom2dAdaptor_Curve) -> None: ...
	def AddDomain(self, Domain: HatchGen_Domain) -> None: ...
	def AddPoint(self, Point: HatchGen_PointOnHatching, Confusion: float) -> None: ...
	def ChangeCurve(self) -> Geom2dAdaptor_Curve: ...
	def ChangePoint(self, Index: int) -> HatchGen_PointOnHatching: ...
	def ClassificationPoint(self) -> gp_Pnt2d: ...
	def ClrDomains(self) -> None: ...
	def ClrPoints(self) -> None: ...
	def Curve(self) -> Geom2dAdaptor_Curve: ...
	def Domain(self, Index: int) -> HatchGen_Domain: ...
	@overload
	def IsDone(self, Flag: bool) -> None: ...
	@overload
	def IsDone(self) -> bool: ...
	def NbDomains(self) -> int: ...
	def NbPoints(self) -> int: ...
	def Point(self, Index: int) -> HatchGen_PointOnHatching: ...
	def RemDomain(self, Index: int) -> None: ...
	def RemPoint(self, Index: int) -> None: ...
	@overload
	def Status(self, theStatus: HatchGen_ErrorStatus) -> None: ...
	@overload
	def Status(self) -> HatchGen_ErrorStatus: ...
	@overload
	def TrimDone(self, Flag: bool) -> None: ...
	@overload
	def TrimDone(self) -> bool: ...
	@overload
	def TrimFailed(self, Flag: bool) -> None: ...
	@overload
	def TrimFailed(self) -> bool: ...

class Geom2dHatch_Intersector(Geom2dInt_GInter):
	@overload
	def __init__(self, Confusion: float, Tangency: float) -> None: ...
	@overload
	def __init__(self) -> None: ...
	def ConfusionTolerance(self) -> float: ...
	def Intersect(self, C1: Geom2dAdaptor_Curve, C2: Geom2dAdaptor_Curve) -> None: ...
	def LocalGeometry(self, E: Geom2dAdaptor_Curve, U: float, T: gp_Dir2d, N: gp_Dir2d) -> float: ...
	def Perform(self, L: gp_Lin2d, P: float, Tol: float, E: Geom2dAdaptor_Curve) -> None: ...
	def SetConfusionTolerance(self, Confusion: float) -> None: ...
	def SetTangencyTolerance(self, Tangency: float) -> None: ...
	def TangencyTolerance(self) -> float: ...

# harray1 classes
# harray2 classes
# hsequence classes

